@@ -21,7 +21,6 @@ except ImportError:
     # Try backported to PY<37 `importlib_resources`.
     import importlib_resources as pkg_resources
 import importlib
-import six
 from cfnlint.decode.node import dict_node, list_node, str_node
 from cfnlint.data import CloudSpecs
 try:
@@ -312,7 +311,7 @@ def load_metadata(filename):
     """Get the contents of the download metadata file"""
     metadata = {}
     if os.path.exists(filename):
-        with open(filename, 'r') as metadata_file:
+        with open(filename, 'r', encoding='utf-8') as metadata_file:
             metadata = json.load(metadata_file)
     return metadata
 
@@ -323,7 +322,7 @@ def save_metadata(metadata, filename):
     if not os.path.exists(dirname):
         os.mkdir(dirname)
 
-    with open(filename, 'w') as metadata_file:
+    with open(filename, 'w', encoding='utf-8') as metadata_file:
         json.dump(metadata, metadata_file)
 
 
@@ -407,10 +406,10 @@ def is_custom_resource(resource_type):
 def bool_compare(first, second):
     """ Compare strings to boolean values """
 
-    if isinstance(first, six.string_types):
+    if isinstance(first, str):
         first = bool(first.lower() in ['true', 'True'])
 
-    if isinstance(second, six.string_types):
+    if isinstance(second, str):
         second = bool(second.lower() in ['true', 'True'])
 
     return first is second
@@ -514,7 +513,7 @@ def override_specs(override_spec_file):
     """Override specs file"""
     try:
         filename = override_spec_file
-        with open(filename) as fp:
+        with open(filename, encoding='utf-8') as fp:
             custom_spec_data = json.load(fp)
 
         set_specs(custom_spec_data)
